# Utils (Base)

General utilities complimenting and expanding on standard python.

## Setup & Install

https://pypi.org/project/utils_base-nuuuwan/#history

```
pip install utils_base-nuuuwan
```

## Version History

### 1.0.10 (NEXT VERSION)

### 1.0.9 (CURRENT VERSION)

* Moved console constants to constants folder
* Removed _log, added Log.main etc
* Added TimeFormat(...).formatNow
* Cleaned-up TimeUnit and TimeId functions
* Refactored Hash, Parallel (mr) and XML

### 1.0.8 

* Enable Log to process non strings
* Use new pyl_build_inits (MIGHT BREAK)

### 1.0.7 

* Fix log ignore BUG (Take 2)

### 1.0.6 

* Fix log ignore BUG

### 1.0.5

* Added Console, improved Log
* Added TimeFormat.format

### 1.0.4 

* Fixed geo init bug

### 1.0.3 

* Added image
* Deprecated Color
* Deprecated Table
* List: Added map and filter
* Added parse_int and parse_float
* Added Geo

### 1.0.2 
* [#1](https://github.com/nuuuwan/utils_base/issues/1) - complete.
* Changed log color logging.INFO: textColor.GREEN
* Added unittest for _log; Changed default name to blank.
* Removed dependency on py_console
* Added from utils_base.xmlx import _

### 1.0.1
* [#4](https://github.com/nuuuwan/utils_base/issues/4)
* [#3](https://github.com/nuuuwan/utils_base/issues/3)
* [#2](https://github.com/nuuuwan/utils_base/issues/2)
* [#1](https://github.com/nuuuwan/utils_base/issues/1) - partially

### 1.0.0 

* Base Version